var atom__macros_8h =
[
    [ "IMP_ATOM_TYPE_INDEX", "atom__macros_8h.html#a4958479b05277578632694f97786d075", null ],
    [ "IMP_FORCE_FIELD_PARAMETERS", "atom__macros_8h.html#aea73ded316726728c66938fa1ae5c7be", null ],
    [ "IMP_HIERARCHY_TYPE_INDEX", "atom__macros_8h.html#a13aefecdd05431ee855c372d9240aa92", null ],
    [ "IMP_MOL2_SELECTOR", "atom__macros_8h.html#a332d0754ad55c3371368af148340d24c", null ],
    [ "IMP_RESIDUE_TYPE_INDEX", "atom__macros_8h.html#a057f80392f975d8d551d90df2ee94ada", null ]
];